@@ -27,6 +27,9 @@
 
 #include <X11/Xatom.h>
 
+/* For XExtSetCloseDisplay */
+#include <X11/Xlibint.h>
+
 #include "pango-fontmap.h"
 #include "pango-utils.h"
 #include "pangox-private.h"
@@ -215,6 +218,39 @@ pango_x_font_map_class_init (PangoFontMapClass *class)
   class->list_families = pango_x_font_map_list_families;
 }
 
+/*
+ * Hackery to set up notification when a Display is closed
+ */
+static GSList *registered_displays;
+
+static int
+close_display_cb (Display   *display,
+		  XExtCodes *extcodes)
+{
+  pango_x_shutdown_display (display);
+  registered_displays = g_slist_remove (registered_displays, display);
+
+  return 0;
+}
+
+static void
+register_display (Display *display)
+{
+  XExtCodes *extcodes;
+  GSList *tmp_list;
+
+  for (tmp_list = registered_displays; tmp_list; tmp_list = tmp_list->next)
+    {
+      if (tmp_list->data == display)
+	return;
+    }
+
+  registered_displays = g_slist_prepend (registered_displays, display);
+    
+  extcodes = XAddExtension (display);
+  XESetCloseDisplay (display, extcodes->extension, close_display_cb);
+}
+
 static GList *fontmaps = NULL;
 
 /**
@@ -285,6 +321,8 @@ pango_x_font_map_for_display (Display *display)
   xfontmap->resolution = (PANGO_SCALE * 72.27 / 25.4) * ((double) DisplayWidthMM (xfontmap->display, screen) /
 							 DisplayWidth (xfontmap->display, screen));
 
+  register_display (xfontmap->display);
+
   return PANGO_FONT_MAP (xfontmap);
 }
 
@@ -310,7 +348,7 @@ pango_x_shutdown_display (Display *display)
 	{
 	  fontmaps = g_list_delete_link (fontmaps, tmp_list);
 	  pango_x_fontmap_cache_clear (xfontmap);
-	  g_object_unref (G_OBJECT (xfontmap));
+	  g_object_unref (xfontmap);
 
 	  return;
 	}
@@ -444,7 +482,7 @@ pango_x_font_map_load_font (PangoFontMap               *fontmap,
 		{
 		  result = (PangoFont *)xfont;
 
-		  g_object_ref (G_OBJECT (result));
+		  g_object_ref (result);
 		  if (xfont->in_cache)
 		    pango_x_fontmap_cache_remove (fontmap, xfont);
 		  
@@ -1328,10 +1366,10 @@ pango_x_fontmap_cache_add (PangoFontMap    *fontmap,
   if (xfontmap->freed_fonts->length == MAX_FREED_FONTS)
     {
       PangoXFont *old_font = g_queue_pop_tail (xfontmap->freed_fonts);
-      g_object_unref (G_OBJECT (old_font));
+      g_object_unref (old_font);
     }
 
-  g_object_ref (G_OBJECT (xfont));
+  g_object_ref (xfont);
   g_queue_push_head (xfontmap->freed_fonts, xfont);
   xfont->in_cache = TRUE;
 }
@@ -1354,7 +1392,7 @@ pango_x_fontmap_cache_remove (PangoFontMap    *fontmap,
   xfontmap->freed_fonts->length--;
   xfont->in_cache = FALSE;
 
-  g_object_unref (G_OBJECT (xfont));
+  g_object_unref (xfont);
 }
 
 static void
@@ -1536,12 +1574,12 @@ pango_x_face_get_coverage (PangoXFace      *xface,
 		  g_hash_table_insert (coverage_hash, map_entry->info->id, coverage);
 		}
 	  
-	  font_level = pango_coverage_get (coverage, ch);
-	  if (font_level == PANGO_COVERAGE_EXACT && !map_entry->is_exact)
-	    font_level = PANGO_COVERAGE_APPROXIMATE;
-
-	  if (font_level != PANGO_COVERAGE_NONE)
-	    pango_coverage_set (result, ch, font_level);
+	      font_level = pango_coverage_get (coverage, ch);
+	      if (font_level == PANGO_COVERAGE_EXACT && !map_entry->is_exact)
+		font_level = PANGO_COVERAGE_APPROXIMATE;
+	      
+	      if (font_level != PANGO_COVERAGE_NONE)
+		pango_coverage_set (result, ch, font_level);
 	    }
 	}
       
