@@ -138,7 +138,7 @@ _pango_xft_font_new (PangoFontMap               *fontmap,
   xfont->fontmap = fontmap;
   xfont->font_pattern = pattern;
   
-  g_object_ref (G_OBJECT (fontmap));
+  g_object_ref (fontmap);
   xfont->description = _pango_xft_font_desc_from_pattern (pattern, TRUE);
   xfont->xft_font = NULL;
 
@@ -480,8 +480,8 @@ pango_xft_font_get_metrics (PangoFont     *font,
       
 	  info->metrics->approximate_digit_width = extents.width / 10;
 
-	  g_object_unref (G_OBJECT (layout));
-	  g_object_unref (G_OBJECT (context));
+	  g_object_unref (layout);
+	  g_object_unref (context);
 	}
     }
 
@@ -794,6 +794,8 @@ pango_xft_font_get_unknown_glyph (PangoFont *font,
  * pango_xft_font_unlock_face().
  *
  * Returns: the FreeType FT_Face associated with @font.
+ *
+ * Since: 1.2
  **/
 FT_Face
 pango_xft_font_lock_face (PangoFont *font)
@@ -813,6 +815,8 @@ pango_xft_font_lock_face (PangoFont *font)
  *
  * Releases a font previously obtained with
  * pango_xft_font_lock_face().
+ *
+ * Since: 1.2
  **/
 void
 pango_xft_font_unlock_face (PangoFont *font)
@@ -837,6 +841,8 @@ pango_xft_font_unlock_face (PangoFont *font)
  * 
  * Return value: the glyph index, or 0, if the unicode
  *  codepoint doesn't exist in the font.
+ *
+ * Since: 1.2
  **/
 guint
 pango_xft_font_get_glyph (PangoFont *font,
@@ -859,6 +865,8 @@ pango_xft_font_get_glyph (PangoFont *font,
  * Determines whether @font has a glyph for the codepoint @wc.
  * 
  * Return value: %TRUE if @font has the requested codepoint.
+ *
+ * Since: 1.2
  **/
 gboolean
 pango_xft_font_has_char (PangoFont *font,
